@@ -23,21 +23,23 @@
 # not, see <https://opensource.org/licenses/MIT>.
 
 from __future__ import division
+
 import copy
+
 import numpy as np
 import scipy.linalg as la
+
+from . import transform
+from . import utilities as u
+from . import windows
 from .directivities import (
+    CardioidFamily,
     DirectionVector,
     Directivity,
-    CardioidFamily,
     DirectivityPattern,
 )
 from .parameters import constants
-from . import utilities as u
 from .soundsource import build_rir_matrix
-from . import windows
-from . import transform
-
 
 # =========================================================================
 # Free (non-class-member) functions related to beamformer design
@@ -166,7 +168,7 @@ def poisson_2D_array(center, M, d):
         The array of points
     """
 
-    from numpy.random import standard_exponential, randint
+    from numpy.random import randint, standard_exponential
 
     R = d * standard_exponential((2, M)) * (2 * randint(0, 2, (2, M)) - 1)
     R = R.cumsum(axis=1)
@@ -185,7 +187,7 @@ def square_2D_array(center, M, N, phi, d):
         The center of the array
     M: int
         The number of points in the first dimension
-    M: int
+    N: int
         The number of points in the second dimension
     phi: float
         The counterclockwise rotation of the array (from the x-axis)
@@ -450,7 +452,7 @@ class MicrophoneArray(object):
         else:
             self.signals = signals
 
-    def to_wav(self, filename, mono=False, norm=False, bitdepth=np.float):
+    def to_wav(self, filename, mono=False, norm=False, bitdepth=float):
         """
         Save all the signals to wav files.
 
@@ -475,7 +477,7 @@ class MicrophoneArray(object):
         else:
             signal = self.signals.T  # each column is a channel
 
-        float_types = [float, np.float, np.float32, np.float64]
+        float_types = [float, np.float32, np.float64]
 
         if bitdepth in float_types:
             bits = None
@@ -804,9 +806,7 @@ class Beamformer(MicrophoneArray):
         if self.weights is None and self.filters is not None:
             self.weights_from_filters()
         elif self.weights is None and self.filters is None:
-            raise NameError(
-                "Beamforming weights or filters need to be computed" " first."
-            )
+            raise NameError("Beamforming weights or filters need to be computed first.")
 
         phi = np.linspace(-np.pi, np.pi - np.pi / 180, 360)
         freq = self.frequencies
@@ -849,7 +849,7 @@ class Beamformer(MicrophoneArray):
         xticks = [-np.pi, -np.pi / 2, 0, np.pi / 2, np.pi]
         for i, p in enumerate(xticks):
             xticks[i] = np.argmin(np.abs(p - phi))
-        xticklabels = ["$-\pi$", "$-\pi/2$", "0", "$\pi/2$", "$\pi$"]
+        xticklabels = [r"$-\pi$", r"$-\pi/2$", r"0", r"$\pi/2$", r"$\pi$"]
         plt.setp(plt.gca(), "xticks", xticks)
         plt.setp(plt.gca(), "xticklabels", xticklabels)
 
@@ -1313,7 +1313,7 @@ class Beamformer(MicrophoneArray):
         # compute and return SNR
         A = np.dot(g_val.T, H[:, :L])
         num = np.dot(A, A.T)
-        denom = np.dot(np.dot(g_val.T, K_nq), g_val)
+        denom = np.linalg.multi_dot([g_val.T, K_nq, g_val])
 
         return num / denom
 
@@ -1393,7 +1393,7 @@ class Beamformer(MicrophoneArray):
         # compute and return SNR
         A = np.dot(g_val.T, H[:, :L])
         num = np.dot(A, A.T)
-        denom = np.dot(np.dot(g_val.T, K_nq), g_val)
+        denom = np.linalg.multi_dot([g_val.T, K_nq, g_val])
 
         return num / denom
 
@@ -1503,6 +1503,6 @@ class Beamformer(MicrophoneArray):
         # compute and return SNR
         A = np.dot(g_val.T, H[:, :L])
         num = np.dot(A, A.T)
-        denom = np.dot(np.dot(g_val.T, K_nq), g_val)
+        denom = np.linalg.multi_dot([g_val.T, K_nq, g_val])
 
         return num / denom
