@@ -16,9 +16,9 @@ URL: https://catalog.ldc.upenn.edu/ldc93s1
 """
 
 import os
-import numpy as np
 
-from pyroomacoustics import stft
+import numpy as np
+from pyroomacoustics.transform import stft
 
 try:
     import sounddevice as sd
