@@ -27,7 +27,7 @@ import numpy as np
 
 
 class Subspace(object):
-    """
+    r"""
     A class for performing **single channel** noise reduction in the time domain
     via the subspace approach. This implementation is based off of the approach
     presented in:
@@ -130,7 +130,7 @@ class Subspace(object):
                 "Frame length should be even as this method " "performs 50% overlap."
             )
 
-        if data_type is "float64":
+        if data_type == "float64":
             data_type = np.float64
         else:
             data_type = np.float32
@@ -213,7 +213,7 @@ class Subspace(object):
             q1[w, w] = pos_eigenvals[w] / (pos_eigenvals[w] + self.mu)
 
         v_t = np.transpose(-eigenvecs[:, order])
-        self.h_opt[:] = np.real(np.dot(np.dot(np.linalg.pinv(v_t), q1), v_t))
+        self.h_opt[:] = np.real(np.linalg.multi_dot([np.linalg.pinv(v_t), q1, v_t]))
         # self.h_opt = np.dot(np.linalg.lstsq(v_t, q1, rcond=None)[0], v_t)
 
     def update_cov_matrices(self, new_samples):
