@@ -109,8 +109,13 @@ class SoundSource(object):
         self.directivity = directivity
 
     def add_signal(self, signal):
-        """Sets ``SoundSource.signal`` attribute"""
+        """Sets `signal` attribute
 
+        Parameters
+        ----------
+        signal: ndarray
+            a N-length ndarray, representing a sequence of samples generated by the source.
+        """
         self.signal = signal
 
     def distance(self, ref_point):
@@ -237,6 +242,19 @@ class SoundSource(object):
         Compute the room impulse response between the source
         and the microphone whose position is given as an
         argument.
+
+        Parameters
+        ----------
+        mic: ndarray
+            microphone position
+        visibility: int32
+            1 if mic visibile from source, 0 else. Exact type is important for C extension
+        Fs: int
+            sampling frequency
+        t0: float
+            time offset, defaults to 0
+        t_max: None
+            max time, defaults to 1.05 times the propagation time from mic to source
         """
 
         # fractional delay length
