@@ -9,10 +9,13 @@ def test_room_volume():
     # Create the 2D L-shaped room from the floor polygon
     pol = 4 * np.array([[0, 0], [0, 1], [2, 1], [2, 0.5], [1, 0.5], [1, 0]]).T
     r_absor = 0.1
-    room = pra.Room.from_corners(pol, fs=16000, max_order=6, absorption=r_absor)
+    e_abs = 1.0 - (1.0 - r_absor) ** 2
+    room = pra.Room.from_corners(
+        pol, fs=16000, max_order=6, materials=pra.Material(e_abs)
+    )
 
     # Create the 3D room by extruding the 2D by 3 meters
-    room.extrude(3.0, absorption=r_absor)
+    room.extrude(3.0, materials=pra.Material(e_abs))
 
     assert np.allclose(room.get_volume(), 72, atol=eps)
 
@@ -23,10 +26,13 @@ def test_walls_area():
     # Create the 2D L-shaped room from the floor polygon
     pol = 4 * np.array([[0, 0], [0, 1], [2, 1], [2, 0.5], [1, 0.5], [1, 0]]).T
     r_absor = 0.1
-    room = pra.Room.from_corners(pol, fs=16000, max_order=6, absorption=r_absor)
+    e_abs = 1.0 - (1.0 - r_absor) ** 2
+    room = pra.Room.from_corners(
+        pol, fs=16000, max_order=6, materials=pra.Material(e_abs)
+    )
 
     # Create the 3D room by extruding the 2D by 3 meters
-    room.extrude(3.0, absorption=r_absor)
+    room.extrude(3.0, materials=pra.Material(e_abs))
 
     assert np.allclose(room.wall_area(room.walls[0]), 6, atol=eps)
     assert np.allclose(room.wall_area(room.walls[1]), 12, atol=eps)
